from setuptools import setup

setup(name='vinclab_distri',
      version='0.1',
      description='Gaussian and Binomail distributions',
      packages=['vinclab_distri'],
      autor = 'Vincent Salas',
      author_email = 'contact@vincentsalas.fr',
      zip_safe=False)
